@@ -1,18 +1,18 @@
 //! utils for the iterator protocol
 
-use crate::eserror::EsError;
 use crate::quickjs_utils::{functions, objects, primitives};
 use crate::valueref::JSValueRef;
+use hirofa_utils::js_utils::JsError;
 use libquickjs_sys as q;
 
 /// iterate over an object conforming to the [iterator](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Iteration_protocols#the_iterator_protocol) protocol
 /// # Safety
 /// please ensure that the QuickjsContext corresponding to the passed JSContext is still valid
-pub unsafe fn iterate<C: Fn(JSValueRef) -> Result<R, EsError>, R>(
+pub unsafe fn iterate<C: Fn(JSValueRef) -> Result<R, JsError>, R>(
     ctx: *mut q::JSContext,
     iterator_ref: &JSValueRef,
     consumer_producer: C,
-) -> Result<Vec<R>, EsError> {
+) -> Result<Vec<R>, JsError> {
     let mut res = vec![];
 
     loop {
