@@ -1,11 +1,11 @@
 //! Utils for working with objects
 
-use crate::eserror::EsError;
 use crate::quickjs_utils::properties::JSPropertyEnumRef;
 use crate::quickjs_utils::{atoms, functions, get_constructor, get_global};
 use crate::quickjscontext::QuickJsContext;
 use crate::quickjsruntime::{make_cstring, QuickJsRuntime};
 use crate::valueref::JSValueRef;
+use hirofa_utils::js_utils::JsError;
 use libquickjs_sys as q;
 
 /// get a namespace object
@@ -25,7 +25,7 @@ pub fn get_namespace_q(
     context: &QuickJsContext,
     namespace: Vec<&str>,
     create_if_absent: bool,
-) -> Result<JSValueRef, EsError> {
+) -> Result<JSValueRef, JsError> {
     unsafe { get_namespace(context.context, namespace, create_if_absent) }
 }
 
@@ -35,7 +35,7 @@ pub unsafe fn get_namespace(
     context: *mut q::JSContext,
     namespace: Vec<&str>,
     create_if_absent: bool,
-) -> Result<JSValueRef, EsError> {
+) -> Result<JSValueRef, JsError> {
     log::trace!("objects::get_namespace({})", namespace.join("."));
 
     let mut obj = get_global(context);
@@ -51,7 +51,7 @@ pub unsafe fn get_namespace(
                 set_property2(context, &obj, p_name, &sub, 0)?;
             } else {
                 log::trace!("objects::get_namespace -> is null -> err");
-                return Err(EsError::new_string(format!(
+                return Err(JsError::new_string(format!(
                     "could not find namespace part: {}",
                     p_name
                 )));
@@ -73,7 +73,7 @@ pub unsafe fn construct_object(
     ctx: *mut q::JSContext,
     constructor_ref: &JSValueRef,
     args: Vec<JSValueRef>,
-) -> Result<JSValueRef, EsError> {
+) -> Result<JSValueRef, JsError> {
     let arg_count = args.len() as i32;
 
     let mut qargs = args.iter().map(|a| *a.borrow_value()).collect::<Vec<_>>();
@@ -91,7 +91,7 @@ pub unsafe fn construct_object(
         if let Some(ex) = QuickJsContext::get_exception(ctx) {
             Err(ex)
         } else {
-            Err(EsError::new_str(
+            Err(JsError::new_str(
                 "construct_object failed but could not get ex",
             ))
         }
@@ -101,18 +101,18 @@ pub unsafe fn construct_object(
 }
 
 /// create a new simple object, e.g. `let obj = {};`
-pub fn create_object_q(q_ctx: &QuickJsContext) -> Result<JSValueRef, EsError> {
+pub fn create_object_q(q_ctx: &QuickJsContext) -> Result<JSValueRef, JsError> {
     unsafe { create_object(q_ctx.context) }
 }
 
 /// create a new simple object, e.g. `let obj = {};`
 /// # Safety
 /// when passing a context ptr please be sure that the corresponding QuickJsContext is still active
-pub unsafe fn create_object(context: *mut q::JSContext) -> Result<JSValueRef, EsError> {
+pub unsafe fn create_object(context: *mut q::JSContext) -> Result<JSValueRef, JsError> {
     let obj = q::JS_NewObject(context);
     let obj_ref = JSValueRef::new(context, obj, false, true, "objects::create_object");
     if obj_ref.is_exception() {
-        return Err(EsError::new_str("Could not create object"));
+        return Err(JsError::new_str("Could not create object"));
     }
     Ok(obj_ref)
 }
@@ -123,7 +123,7 @@ pub fn set_property_q(
     obj_ref: &JSValueRef,
     prop_name: &str,
     prop_ref: &JSValueRef,
-) -> Result<(), EsError> {
+) -> Result<(), JsError> {
     unsafe { set_property(q_ctx.context, obj_ref, prop_name, prop_ref) }
 }
 
@@ -135,7 +135,7 @@ pub unsafe fn set_property(
     obj_ref: &JSValueRef,
     prop_name: &str,
     prop_ref: &JSValueRef,
-) -> Result<(), EsError> {
+) -> Result<(), JsError> {
     set_property2(
         context,
         obj_ref,
@@ -179,7 +179,7 @@ pub fn set_property2_q(
     prop_name: &str,
     prop_ref: &JSValueRef,
     flags: i32,
-) -> Result<(), EsError> {
+) -> Result<(), JsError> {
     unsafe { set_property2(q_ctx.context, obj_ref, prop_name, prop_ref, flags) }
 }
 
@@ -192,7 +192,7 @@ pub unsafe fn set_property2(
     prop_name: &str,
     prop_ref: &JSValueRef,
     flags: i32,
-) -> Result<(), EsError> {
+) -> Result<(), JsError> {
     log::trace!("set_property2: {}", prop_name);
 
     let ckey = make_cstring(prop_name)?;
@@ -221,7 +221,7 @@ pub unsafe fn set_property2(
     );
     log::trace!("set_property2 / 3");
     if ret < 0 {
-        return Err(EsError::new_str("Could not add property to object"));
+        return Err(JsError::new_str("Could not add property to object"));
     }
     log::trace!("set_property2 / 4");
     Ok(())
@@ -235,8 +235,8 @@ pub unsafe fn set_property2(
 /// use quickjs_runtime::quickjs_utils::functions::new_function_q;
 /// use quickjs_runtime::quickjs_utils::primitives::from_i32;
 /// use quickjs_runtime::quickjs_utils::{new_null_ref, get_global_q};
-/// use quickjs_runtime::esscript::EsScript;
-/// use quickjs_runtime::eserror::EsError;
+/// use hirofa_utils::js_utils::Script;
+/// use quickjs_runtime::JsError::JsError;
 /// let rt = EsRuntimeBuilder::new().build();
 /// rt.add_to_event_queue_sync(|q_js_rt| {
 ///     let q_ctx = q_js_rt.get_main_context();
@@ -253,7 +253,7 @@ pub unsafe fn set_property2(
 ///     let global = get_global_q(q_ctx);
 ///     set_property_q(q_ctx, &global, "testObj431", &obj).ok().expect("set prop on global failed");
 /// });
-/// rt.eval_sync(EsScript::new("define_getter_setter_q.es", "testObj431.someProperty = 'hello prop';")).ok().expect("script failed");
+/// rt.eval_sync(Script::new("define_getter_setter_q.es", "testObj431.someProperty = 'hello prop';")).ok().expect("script failed");
 /// ```
 pub fn define_getter_setter_q(
     q_ctx: &QuickJsContext,
@@ -261,7 +261,7 @@ pub fn define_getter_setter_q(
     prop_name: &str,
     getter_func_ref: &JSValueRef,
     setter_func_ref: &JSValueRef,
-) -> Result<(), EsError> {
+) -> Result<(), JsError> {
     unsafe {
         define_getter_setter(
             q_ctx.context,
@@ -283,7 +283,7 @@ pub unsafe fn define_getter_setter(
     prop_name: &str,
     getter_func_ref: &JSValueRef,
     setter_func_ref: &JSValueRef,
-) -> Result<(), EsError> {
+) -> Result<(), JsError> {
     /*
      pub fn JS_DefinePropertyGetSet(
         ctx: *mut JSContext,
@@ -321,7 +321,7 @@ pub unsafe fn define_getter_setter(
         if let Some(err) = QuickJsContext::get_exception(context) {
             Err(err)
         } else {
-            Err(EsError::new_str(
+            Err(JsError::new_str(
                 "Unknown error while creating getter setter",
             ))
         }
@@ -335,7 +335,7 @@ pub fn get_property_q(
     q_ctx: &QuickJsContext,
     obj_ref: &JSValueRef,
     prop_name: &str,
-) -> Result<JSValueRef, EsError> {
+) -> Result<JSValueRef, JsError> {
     unsafe { get_property(q_ctx.context, obj_ref, prop_name) }
 }
 
@@ -346,9 +346,9 @@ pub unsafe fn get_property(
     context: *mut q::JSContext,
     obj_ref: &JSValueRef,
     prop_name: &str,
-) -> Result<JSValueRef, EsError> {
+) -> Result<JSValueRef, JsError> {
     if obj_ref.is_null() || obj_ref.is_undefined() {
-        return Err(EsError::new_str(
+        return Err(JsError::new_str(
             "could not get prop from null or undefined",
         ));
     }
@@ -373,7 +373,7 @@ pub unsafe fn get_property(
 pub fn get_own_property_names_q(
     q_ctx: &QuickJsContext,
     obj_ref: &JSValueRef,
-) -> Result<JSPropertyEnumRef, EsError> {
+) -> Result<JSPropertyEnumRef, JsError> {
     unsafe { get_own_property_names(q_ctx.context, obj_ref) }
 }
 
@@ -383,7 +383,7 @@ pub fn get_own_property_names_q(
 pub unsafe fn get_own_property_names(
     context: *mut q::JSContext,
     obj_ref: &JSValueRef,
-) -> Result<JSPropertyEnumRef, EsError> {
+) -> Result<JSPropertyEnumRef, JsError> {
     let mut properties: *mut q::JSPropertyEnum = std::ptr::null_mut();
     let mut count: u32 = 0;
 
@@ -396,7 +396,7 @@ pub unsafe fn get_own_property_names(
         flags,
     );
     if ret != 0 {
-        return Err(EsError::new_str("Could not get object properties"));
+        return Err(JsError::new_str("Could not get object properties"));
     }
 
     let enum_ref = JSPropertyEnumRef::new(context, properties, count);
@@ -407,7 +407,7 @@ pub unsafe fn get_own_property_names(
 pub fn get_property_names_q(
     q_ctx: &QuickJsContext,
     obj_ref: &JSValueRef,
-) -> Result<Vec<String>, EsError> {
+) -> Result<Vec<String>, JsError> {
     unsafe { get_property_names(q_ctx.context, obj_ref) }
 }
 
@@ -417,7 +417,7 @@ pub fn get_property_names_q(
 pub unsafe fn get_property_names(
     context: *mut q::JSContext,
     obj_ref: &JSValueRef,
-) -> Result<Vec<String>, EsError> {
+) -> Result<Vec<String>, JsError> {
     let enum_ref = get_own_property_names(context, obj_ref)?;
 
     let mut names = vec![];
@@ -434,9 +434,9 @@ pub fn traverse_properties_q<V, R>(
     q_ctx: &QuickJsContext,
     obj_ref: &JSValueRef,
     visitor: V,
-) -> Result<Vec<R>, EsError>
+) -> Result<Vec<R>, JsError>
 where
-    V: Fn(&str, JSValueRef) -> Result<R, EsError>,
+    V: Fn(&str, &JSValueRef) -> Result<R, JsError>,
 {
     unsafe { traverse_properties(q_ctx.context, obj_ref, visitor) }
 }
@@ -447,9 +447,9 @@ pub unsafe fn traverse_properties<V, R>(
     context: *mut q::JSContext,
     obj_ref: &JSValueRef,
     visitor: V,
-) -> Result<Vec<R>, EsError>
+) -> Result<Vec<R>, JsError>
 where
-    V: Fn(&str, JSValueRef) -> Result<R, EsError>,
+    V: Fn(&str, &JSValueRef) -> Result<R, JsError>,
 {
     let enum_ref = get_own_property_names(context, obj_ref)?;
 
@@ -474,10 +474,10 @@ where
             "objects::traverse_properties raw_value",
         );
         if prop_val_ref.is_exception() {
-            return Err(EsError::new_str("Could not get object property"));
+            return Err(JsError::new_str("Could not get object property"));
         }
 
-        let r = visitor(prop_name, prop_val_ref)?;
+        let r = visitor(prop_name, &prop_val_ref)?;
 
         result.push(r);
     }
@@ -488,7 +488,7 @@ where
 pub fn is_instance_of_q(
     q_ctx: &QuickJsContext,
     obj_ref: &JSValueRef,
-    constructor_ref: JSValueRef,
+    constructor_ref: &JSValueRef,
 ) -> bool {
     unsafe { is_instance_of(q_ctx.context, obj_ref, constructor_ref) }
 }
@@ -498,7 +498,7 @@ pub fn is_instance_of_q(
 pub unsafe fn is_instance_of(
     context: *mut q::JSContext,
     obj_ref: &JSValueRef,
-    constructor_ref: JSValueRef,
+    constructor_ref: &JSValueRef,
 ) -> bool {
     if !obj_ref.is_object() {
         return false;
@@ -515,7 +515,7 @@ pub fn is_instance_of_by_name_q(
     context: &QuickJsContext,
     obj_ref: &JSValueRef,
     constructor_name: &str,
-) -> Result<bool, EsError> {
+) -> Result<bool, JsError> {
     unsafe { is_instance_of_by_name(context.context, obj_ref, constructor_name) }
 }
 
@@ -525,7 +525,7 @@ pub unsafe fn is_instance_of_by_name(
     context: *mut q::JSContext,
     obj_ref: &JSValueRef,
     constructor_name: &str,
-) -> Result<bool, EsError> {
+) -> Result<bool, JsError> {
     if !obj_ref.is_object() {
         return Ok(false);
     }
@@ -535,14 +535,14 @@ pub unsafe fn is_instance_of_by_name(
         return Ok(false);
     }
 
-    if is_instance_of(context, obj_ref, constructor_ref) {
+    if is_instance_of(context, obj_ref, &constructor_ref) {
         Ok(true)
     } else {
         // todo check if context is not __main__
         QuickJsRuntime::do_with(|q_js_rt| {
             let main_ctx = q_js_rt.get_main_context();
             let main_constructor_ref = get_constructor(main_ctx.context, constructor_name)?;
-            if is_instance_of(main_ctx.context, obj_ref, main_constructor_ref) {
+            if is_instance_of(main_ctx.context, obj_ref, &main_constructor_ref) {
                 Ok(true)
             } else {
                 Ok(false)
@@ -554,12 +554,12 @@ pub unsafe fn is_instance_of_by_name(
 #[cfg(test)]
 pub mod tests {
     use crate::esruntime::tests::init_test_rt;
-    use crate::esscript::EsScript;
     use crate::quickjs_utils::objects::{
         create_object_q, get_property_names_q, get_property_q, set_property_q,
     };
     use crate::quickjs_utils::primitives::{from_i32, to_i32};
     use crate::quickjs_utils::{get_global_q, primitives};
+    use hirofa_utils::js_utils::Script;
 
     #[test]
     fn test_get_refs() {
@@ -636,7 +636,7 @@ pub mod tests {
             let q_ctx = q_js_rt.get_main_context();
 
             let obj_ref = q_ctx
-                .eval(EsScript::new("test_propnames.es", "({one: 1, two: 2});"))
+                .eval(Script::new("test_propnames.es", "({one: 1, two: 2});"))
                 .ok()
                 .expect("could not get test obj");
             let prop_names = get_property_names_q(q_ctx, &obj_ref)
@@ -686,13 +686,13 @@ pub mod tests {
             q_js_rt.gc();
 
             let a = q_ctx
-                .eval(EsScript::new("test_set_prop.es", "(test_obj);"))
+                .eval(Script::new("test_set_prop.es", "(test_obj);"))
                 .ok()
                 .unwrap()
                 .is_object();
             assert!(a);
             let b = q_ctx
-                .eval(EsScript::new("test_set_prop.es", "(test_obj.test_prop);"))
+                .eval(Script::new("test_set_prop.es", "(test_obj.test_prop);"))
                 .ok()
                 .unwrap()
                 .is_i32();
